==> totvs-log-web-foundation-0.0.9.tgz: package/src/lib/services/message/message.service.spec.ts <==
import { ShowMessageType, ShowMessageLinkActionType, LiteralLoaderMock, MockEmptyI18nBaseService } from 'totvs-log-base-foundation';
import { I18nBaseService } from 'totvs-log-base-foundation';
import { TestBed } from '@angular/core/testing';
import { ThfNotificationService } from '@totvs/thf-ui';

import { ThfNotificationServiceMock } from '../../test-utils/mock/thf-notification-service.mock';
import { MessageService } from './message.service';
import { INTL_CONFIG } from '../intl/intl.service';
import { IntlLiteralsLoaderService } from '../intl/intl-literal-loader.service';
import { TestInjectorModule } from '../../test-utils/test-injector.module.spec';
import { I18nBaseServiceMock } from './../../test-utils/mock/i18n-base-service.mock';

describe('message.service.spec | Pipe de internacionalização', () => {
    let messageService: MessageService;
    let thfNotification;
    beforeEach(() => {
        TestBed.configureTestingModule({
            imports: [
                TestInjectorModule
            ],
            providers: [
                {
                    provide: ThfNotificationService,
                    useFactory: () => thfNotification = ThfNotificationServiceMock.instance()
                },
                {
                    provide: I18nBaseService,
                    useClass: I18nBaseServiceMock
                },
                {
                    provide: INTL_CONFIG,
                    useValue: {
                        url: ' '
                    }
                },
                {
                    provide: IntlLiteralsLoaderService,
                    useFactory: () => LiteralLoaderMock.instance({ warning: 'Aviso Teste', confirm: 'Confirmar teste' })
                },
                MessageService
            ]
        });

        messageService = TestBed.get(MessageService);
    });

    it('MessageService deveria estar instancias ', () => {
        expect(messageService).toBeDefined();
    });

    it('Deveria ter executado o método showNotification sem erros ', () => {
        messageService.displayMessage({
            messageType: ShowMessageType.NotificationInformation,
            messageText: 'Notificação'
        });
        messageService.displayMessage({
            messageType: ShowMessageType.NotificationSuccess,
            messageText: 'Sucesso'
        });
        messageService.displayMessage({
            messageType: ShowMessageType.NotificationError,
            messageText: 'Erro'
        });
        messageService.displayMessage({
            messageType: ShowMessageType.NotificationWarning,
            messageText: 'Aviso'
        });
        expect(thfNotification.information).toHaveBeenCalledWith({
            message: 'Notificação',
            orientation: 1,
            action: undefined,
            actionLabel: undefined
        });
        expect(thfNotification.success).toHaveBeenCalledWith({
            message: 'Sucesso',
            orientation: 1,
            action: undefined,
            actionLabel: undefined
        });
        expect(thfNotification.error).toHaveBeenCalledWith({
            message: 'Erro',
            orientation: 1,
            action: undefined,
            actionLabel: undefined
        });
        expect(thfNotification.warning).toHaveBeenCalledWith({
            message: 'Aviso',
            orientation: 1,
            action: undefined,
            actionLabel: undefined
        });
    });

    it('Code coverage | código deveria executar com sucesso ', () => {
        messageService.displayMessage({
            messageType: ShowMessageType.DialogAlert,
            messageText: 'Alerta'
        });
        messageService.displayMessage({
            messageType: ShowMessageType.DialogConfirmation,
            messageText: 'Confirmação'
        });
        messageService.displayMessage({
            messageType: ShowMessageType.DialogConfirmation,
            messageText: 'Confirmação',
            messageTitle: 'Título'
        });
        const showMessageOptions = {
            messageType: ShowMessageType.DialogConfirmation,
            messageText: 'Confirmação',
            messageLinkActionType: ShowMessageLinkActionType.LinkNewTab,
            messageLinkAction: 'link'
        };
        messageService.displayMessage(showMessageOptions);
        expect(showMessageOptions.messageLinkAction).toBeDefined();
        messageService.displayMessage({
            messageType: ShowMessageType.NotificationInformation,
            messageText: 'Confirmação',
            messageLinkActionType: ShowMessageLinkActionType.Method,
            messageLinkAction: () => { }
        });
        showMessageOptions.messageType = ShowMessageType.NotificationInformation;
        showMessageOptions.messageLinkAction = 'link';
        messageService.displayMessage(showMessageOptions);
    });

});

==> totvs-log-web-foundation-1.0.0.tgz: package/src/lib/services/message/message.service.spec.ts <==
import { ShowMessageType, ShowMessageLinkActionType, LiteralLoaderMock, MockEmptyI18nBaseService } from 'totvs-log-base-foundation';
import { I18nBaseService } from 'totvs-log-base-foundation';
import { TestBed } from '@angular/core/testing';
import { PoNotificationService } from '@portinari/portinari-ui';

import { PoNotificationServiceMock } from '../../test-utils/mock/po-notification-service.mock';
import { MessageService } from './message.service';
import { INTL_CONFIG } from '../intl/intl.service';
import { IntlLiteralsLoaderService } from '../intl/intl-literal-loader.service';
import { TestInjectorModule } from '../../test-utils/test-injector.module.spec';
import { I18nBaseServiceMock } from './../../test-utils/mock/i18n-base-service.mock';

describe('message.service.spec | Pipe de internacionalização', () => {
    let messageService: MessageService;
    let poNotification;
    beforeEach(() => {
        TestBed.configureTestingModule({
            imports: [
                TestInjectorModule
            ],
            providers: [
                {
                    provide: PoNotificationService,
                    useFactory: () => poNotification = PoNotificationServiceMock.instance()
                },
                {
                    provide: I18nBaseService,
                    useClass: I18nBaseServiceMock
                },
                {
                    provide: INTL_CONFIG,
                    useValue: {
                        url: ' '
                    }
                },
                {
                    provide: IntlLiteralsLoaderService,
                    useFactory: () => LiteralLoaderMock.instance({ warning: 'Aviso Teste', confirm: 'Confirmar teste' })
                },
                MessageService
            ]
        });

        messageService = TestBed.get(MessageService);
    });

    it('MessageService deveria estar instancias ', () => {
        expect(messageService).toBeDefined();
    });

    it('Deveria ter executado o método showNotification sem erros ', () => {
        messageService.displayMessage({
            messageType: ShowMessageType.NotificationInformation,
            messageText: 'Notificação'
        });
        messageService.displayMessage({
            messageType: ShowMessageType.NotificationSuccess,
            messageText: 'Sucesso'
        });
        messageService.displayMessage({
            messageType: ShowMessageType.NotificationError,
            messageText: 'Erro'
        });
        messageService.displayMessage({
            messageType: ShowMessageType.NotificationWarning,
            messageText: 'Aviso'
        });
        expect(poNotification.information).toHaveBeenCalledWith({
            message: 'Notificação',
            orientation: 1,
            action: undefined,
            actionLabel: undefined
        });
        expect(poNotification.success).toHaveBeenCalledWith({
            message: 'Sucesso',
            orientation: 1,
            action: undefined,
            actionLabel: undefined
        });
        expect(poNotification.error).toHaveBeenCalledWith({
            message: 'Erro',
            orientation: 1,
            action: undefined,
            actionLabel: undefined
        });
        expect(poNotification.warning).toHaveBeenCalledWith({
            message: 'Aviso',
            orientation: 1,
            action: undefined,
            actionLabel: undefined
        });
    });

    it('Code coverage | código deveria executar com sucesso ', () => {
        messageService.displayMessage({
            messageType: ShowMessageType.DialogAlert,
            messageText: 'Alerta'
        });
        messageService.displayMessage({
            messageType: ShowMessageType.DialogConfirmation,
            messageText: 'Confirmação'
        });
        messageService.displayMessage({
            messageType: ShowMessageType.DialogConfirmation,
            messageText: 'Confirmação',
            messageTitle: 'Título'
        });
        const showMessageOptions = {
            messageType: ShowMessageType.DialogConfirmation,
            messageText: 'Confirmação',
            messageLinkActionType: ShowMessageLinkActionType.LinkNewTab,
            messageLinkAction: 'link'
        };
        messageService.displayMessage(showMessageOptions);
        expect(showMessageOptions.messageLinkAction).toBeDefined();
        messageService.displayMessage({
            messageType: ShowMessageType.NotificationInformation,
            messageText: 'Confirmação',
            messageLinkActionType: ShowMessageLinkActionType.Method,
            messageLinkAction: () => { }
        });
        showMessageOptions.messageType = ShowMessageType.NotificationInformation;
        showMessageOptions.messageLinkAction = 'link';
        messageService.displayMessage(showMessageOptions);
    });

});
